@@ -31,8 +31,8 @@ class SalutAdvancedOptionsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit SalutAdvancedOptionsWidget(ParameterEditModel *model,
-                                        QWidget *parent = 0);
-    virtual ~SalutAdvancedOptionsWidget();
+                                        QWidget *parent = nullptr);
+    ~SalutAdvancedOptionsWidget() override;
 
 private:
     Q_DISABLE_COPY(SalutAdvancedOptionsWidget)
